==> Pyrogram-0.6.4-py3-none-any.whl: pyrogram/api/types/update_channel_pinned_message.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class UpdateChannelPinnedMessage(Object):
    """
    Attributes:
        ID (:obj:`int`): ``0x98592475``

    Args:
        channel_id: :obj:`int`
        id: :obj:`int`
    """
    ID = 0x98592475

    def __init__(self, channel_id, id):
        self.channel_id = channel_id  # int
        self.id = id  # int

    @staticmethod
    def read(b: BytesIO, *args) -> "UpdateChannelPinnedMessage":
        # No flags
        
        channel_id = Int.read(b)
        
        id = Int.read(b)
        
        return UpdateChannelPinnedMessage(channel_id, id)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Int(self.channel_id))
        
        b.write(Int(self.id))
        
        return b.getvalue()

==> Pyrogram-0.7.1-py3-none-any.whl: pyrogram/api/types/update_channel_pinned_message.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class UpdateChannelPinnedMessage(Object):
    """Attributes:
        ID: ``0x98592475``

    Args:
        channel_id: ``int`` ``32-bit``
        id: ``int`` ``32-bit``
    """
    ID = 0x98592475

    def __init__(self, channel_id, id):
        self.channel_id = channel_id  # int
        self.id = id  # int

    @staticmethod
    def read(b: BytesIO, *args) -> "UpdateChannelPinnedMessage":
        # No flags
        
        channel_id = Int.read(b)
        
        id = Int.read(b)
        
        return UpdateChannelPinnedMessage(channel_id, id)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Int(self.channel_id))
        
        b.write(Int(self.id))
        
        return b.getvalue()
